#ifndef RIVET_ZEUSTEMPLATE_HH
#define RIVET_ZEUSTEMPLATE_HH

#include "Rivet/Analysis.hh"
#include "Rivet/Projections/JacquetBlondelY.hh"
#include "Rivet/Projections/FastJets.hh"
#include "Rivet/RivetAIDA.fhh"

namespace Rivet {
 
  class Zeus_template : public Analysis{
    
  public:
    
    // no-argument constructor
    Zeus_template(){
      
      setBeams(PROTON, ELECTRON);

      //select particles within a range -4<eta<4 
      //(not really necessary since the analysis looks for eta<2.5 anyway!
      FinalState fs(-4.0,4.0);
      //add the y of the event to the analysis
      addProjection(JacquetBlondelY(fs), "YJB");
      //run KT jet finding on those final state particles
      addProjection(FastJets(fs, FastJets::KT, 1.0), "KT1Jets");
      
      //call this method if the plots are a cross section and not number of events
      setNeedsCrossSection(true);
      
    }
    
    //used to create this analysis at runtime
    static Analysis* create() { 
      return new Zeus_template(); 
    }
    
    //the spires ID for identification of this analysis
    string spiresId() const{
      return "7270267";
    }
    
    string experiment()const{
      return "ZEUS";
    }
    
    string year()const{
     return "2007"; 
    }
    
    //These must be present for all analyses:
    //defined in the .cc file
    void init();
    void analyze(const Event &evt);
    void finalize();
    
    
  private:
    
    //a histogram of jet ET
    
    AIDA::IHistogram1D * _histo;
    
  };
}

#endif
